
# neat_ml_schema


**metamodel version:** 1.7.0

**version:** None


A schema generated by LinkML for specifying graph ML pipelines in NEAT.


### Classes

 * [ApplyTrainedModel](ApplyTrainedModel.md) - Trained model used for prediction.
 * [ApplyTrainedModelsContainer](ApplyTrainedModelsContainer.md) - A container with multiple classifiers in it.
 * [Classifier](Classifier.md) - ML classifiers to be trained-tested-validated and applied for predictions.
 * [ClassifierCallback](ClassifierCallback.md) - Utilities called at certain points during model training.
 * [ClassifierCallbackContainer](ClassifierCallbackContainer.md) - A container of classifier callbacks.
 * [ClassifierContainer](ClassifierContainer.md) - A container with multiple classifiers in it.
 * [ClassifierFitParams](ClassifierFitParams.md) - Paramters for fitting a classifier.
 * [ClassifierParams](ClassifierParams.md) - Parameters needed to define a classifier.
 * [EmbeddingsConfig](EmbeddingsConfig.md) - Embeddings configuration.
 * [EnsmallenRunConfig](EnsmallenRunConfig.md) - All params used by ensmallen's csv_reader
 * [FileResource](FileResource.md) - Path (or url) and description of source files (tar.gz).
 * [FileResourceContainer](FileResourceContainer.md) - A container of paths and descriptions
 * [GraphDataConfiguration](GraphDataConfiguration.md) - Configuration for the graph training and validation data for ML pipeline.
 * [Layer](Layer.md) - Layers for a neural network.
 * [LayerContainer](LayerContainer.md) - A container of neural network layers.
 * [LayerParams](LayerParams.md) - Parameters for each layer of a neural network.
 * [Metric](Metric.md) - Metrics of a trained classifier (model).
 * [MetricContainer](MetricContainer.md) - Container of metrics for a trained classifier.
 * [NeatConfiguration](NeatConfiguration.md) - Root class for the schema.
 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md) - Node embeddings parameters.
 * [NodeType](NodeType.md) - Source node or Destination node.
 * [PosNegData](PosNegData.md) - File paths for positive an negative edge data.
 * [SkLearnParams](SkLearnParams.md) - Parameters specific to the SKLearn library.
 * [TFKerasParams](TFKerasParams.md) - Parameters specific to the Tensorflow Keras library.
 * [Target](Target.md) - Path for output to be saved.
 * [TrainValidData](TrainValidData.md) - Postive and negative training and validation graph data filepaths.
 * [Upload](Upload.md) - Configuration for uploading to Amazon S3 bucket.

### Mixins


### Slots

 * [➞cutoff](applyTrainedModel__cutoff.md) - Cutoff filter.
 * [➞model_id](applyTrainedModel__model_id.md) - Key of the model to be used.
 * [➞node_types](applyTrainedModel__node_types.md) - Type of nodes.
 * [➞outfile](applyTrainedModel__outfile.md) - File path for saving results.
 * [➞models](applyTrainedModelsContainer__models.md) - Models that need to be used for link prediction.
 * [➞callbacks](classifierCallbackContainer__callbacks.md) - Callbacks.
 * [➞min_delta](classifierCallback__min_delta.md) - Minimum change in the monitored quantity to qualify as an improvement, i.e. an absolute change of less than min_delta, will count as no improvement.
 * [➞mode](classifierCallback__mode.md) - One of {"auto", "min", "max"}. In min mode, training will stop when the quantity monitored has stopped decreasing; in "max" mode it will stop when the quantity monitored has stopped increasing; in "auto" mode, the direction is automatically inferred from the name of the monitored quantity.
 * [➞monitor](classifierCallback__monitor.md) - Quantity to be monitored.
 * [➞patience](classifierCallback__patience.md) - Number of epochs with no improvement after which training will be stopped.
 * [➞type](classifierCallback__type.md) - Type of callback.
 * [➞verbose](classifierCallback__verbose.md) - Verbosity mode, 0 or 1. Mode 0 is silent, and mode 1 displays messages when the callback takes an action.
 * [➞classifiers](classifierContainer__classifiers.md) - Classifier details.
 * [➞batch_size](classifierFitParams__batch_size.md)
 * [➞callbacks_list](classifierFitParams__callbacks_list.md) - Container of callbacks.
 * [➞epochs](classifierFitParams__epochs.md) - Number of epochs to run for training.
 * [➞sklearn_params](classifierParams__sklearn_params.md) - Parameters specific to sklearn.
 * [➞tf_keras_params](classifierParams__tf_keras_params.md) - Parameters specific to Tensorflow/Keras
 * [➞classifier_id](classifier__classifier_id.md) - Key to identify the classifier and associated parameters.
 * [➞classifier_name](classifier__classifier_name.md) - Name of the classifier.
 * [➞classifier_type](classifier__classifier_type.md) - Type of classifier.
 * [➞edge_method](classifier__edge_method.md) - Edge method.
 * [➞history_filename](classifier__history_filename.md) - File name for saving history.
 * [➞outfile](classifier__outfile.md) - Fie path for saving output.
 * [➞parameters](classifier__parameters.md) - Parameters to be passed for building classifier.
 * [➞filename](embeddingsConfig__filename.md) - Embeddings file name.
 * [➞history_filename](embeddingsConfig__history_filename.md) - Embeddings history file name.
 * [➞node_embeddings_params](embeddingsConfig__node_embeddings_params.md) - Node embeddings parameters.
 * [➞tsne_filename](embeddingsConfig__tsne_filename.md) - File name for the TSNE plot.
 * [➞default_edge_type](ensmallenRunConfig__default_edge_type.md) - The edge type to be used when the edge type for a given edge in the edge file is None.
 * [➞default_node_type](ensmallenRunConfig__default_node_type.md) - The node type to be used when the node type for a given node in the node file is None.
 * [➞default_weight](ensmallenRunConfig__default_weight.md) - The edge weight to be used when the edge weight for a given edge in the edge file is None.
 * [➞destinations_column](ensmallenRunConfig__destinations_column.md) - The name of the column of the edges file from where to load the destinaton nodes.
 * [➞destinations_column_number](ensmallenRunConfig__destinations_column_number.md) - The number of the column of the edges file from where to load the destinaton nodes.
 * [➞directed](ensmallenRunConfig__directed.md) - Whether to load the graph as directed or undirected.
 * [➞edge_ids_column](ensmallenRunConfig__edge_ids_column.md) - The name of the column of the edges file from where to load the edge IDs.
 * [➞edge_ids_column_number](ensmallenRunConfig__edge_ids_column_number.md) - The number of the column of the edges file from where to load the edge IDs.
 * [➞edge_list_comment_symbol](ensmallenRunConfig__edge_list_comment_symbol.md) - The comment symbol to skip lines in the edges file. Lines starting with this symbol will be skipped.
 * [➞edge_list_edge_types_column](ensmallenRunConfig__edge_list_edge_types_column.md) - The name of the column of the edges file from where to load the edge types.
 * [➞edge_list_edge_types_column_number](ensmallenRunConfig__edge_list_edge_types_column_number.md) - The number of the column of the edges file from where to load the edge types.
 * [➞edge_list_header](ensmallenRunConfig__edge_list_header.md) - Whether the edges file has an header.
 * [➞edge_list_is_complete](ensmallenRunConfig__edge_list_is_complete.md) - Whether to consider the edge list as complete, i.e. the edges are presented in both directions when loading an undirected graph.
 * [➞edge_list_is_correct](ensmallenRunConfig__edge_list_is_correct.md) - Whether the edges file can be assumed to be correct, i.e. does not have something wrong in it. If this parameter is passed as true on a malformed file, the constructor will crash.
 * [➞edge_list_is_sorted](ensmallenRunConfig__edge_list_is_sorted.md) - Whether the edge list is sorted. Note that a sorted edge list has the minimal memory peak, but requires the nodes number and the edges number.
 * [➞edge_list_max_rows_number](ensmallenRunConfig__edge_list_max_rows_number.md) - The maximum number of lines to be loaded from the edges file.
 * [➞edge_list_may_contain_duplicates](ensmallenRunConfig__edge_list_may_contain_duplicates.md) - Whether the edge list may contain duplicates. If the edge list surely DOES NOT contain duplicates, a validation step may be skipped. By default, it is assumed that the edge list may contain duplicates.
 * [➞edge_list_numeric_edge_type_ids](ensmallenRunConfig__edge_list_numeric_edge_type_ids.md) - Whether to load the edge type IDs as numeric from the edge list.
 * [➞edge_list_numeric_node_ids](ensmallenRunConfig__edge_list_numeric_node_ids.md) - Whether to load the edge node IDs as numeric from the edge list.
 * [➞edge_list_rows_to_skip](ensmallenRunConfig__edge_list_rows_to_skip.md) - Number of rows to skip in the edge list file.
 * [➞edge_list_separator](ensmallenRunConfig__edge_list_separator.md) - The separator to use for the edge list. Note that, if None is provided, one will be attempted to be detected automatically between ';', ',', tab or space.
 * [➞edge_list_support_balanced_quotes](ensmallenRunConfig__edge_list_support_balanced_quotes.md) - Whether to support balanced quotes while reading the edge list.
 * [➞edge_path](ensmallenRunConfig__edge_path.md) - The path to the file with the edge list.
 * [➞edge_type_list_comment_symbol](ensmallenRunConfig__edge_type_list_comment_symbol.md) - The comment symbol to skip lines in the edge types file. Lines starting with this symbol will be skipped.
 * [➞edge_type_list_header](ensmallenRunConfig__edge_type_list_header.md) - Whether the edge type file has an header.
 * [➞edge_type_list_is_correct](ensmallenRunConfig__edge_type_list_is_correct.md) - Whether the edge types file can be assumed to be correct, i.e. does not have something wrong in it. If this parameter is passed as true on a malformed file, the constructor will crash.
 * [➞edge_type_list_max_rows_number](ensmallenRunConfig__edge_type_list_max_rows_number.md) - The maximum number of lines to be loaded from the edge types file.
 * [➞edge_type_list_rows_to_skip](ensmallenRunConfig__edge_type_list_rows_to_skip.md) - Number of rows to skip in the edge type list file.
 * [➞edge_type_list_separator](ensmallenRunConfig__edge_type_list_separator.md) - The separator to use for the edge type list. Note that, if None is provided, one will be attempted to be detected automatically between ';', ',', tab or space.
 * [➞edge_type_list_support_balanced_quotes](ensmallenRunConfig__edge_type_list_support_balanced_quotes.md) - Whether to support balanced quotes while reading the edge type list.
 * [➞edge_type_path](ensmallenRunConfig__edge_type_path.md) - The path to the file with the unique edge type names.
 * [➞edge_types_column](ensmallenRunConfig__edge_types_column.md) - The name of the column of the edge types file from where to load the edge types.
 * [➞edge_types_column_number](ensmallenRunConfig__edge_types_column_number.md) - The number of the column of the edge types file from where to load the edge types.
 * [➞edge_types_number](ensmallenRunConfig__edge_types_number.md) - The number of the unique edge types. This will be used in order to allocate the correct size for the data structure.
 * [➞edges_number](ensmallenRunConfig__edges_number.md) - The expected number of edges. Note that this must be the EXACT number of edges in the graph.
 * [➞load_edge_list_in_parallel](ensmallenRunConfig__load_edge_list_in_parallel.md) - Whether to load the edge list in parallel. Note that, if the edge IDs indices are not given, it is NOT possible to load a sorted edge list. Similarly, when loading in parallel, without edge IDs, the edges may not be loaded in a deterministic order.
 * [➞load_edge_type_list_in_parallel](ensmallenRunConfig__load_edge_type_list_in_parallel.md) - Whether to load the edge type list in parallel. When loading in parallel, without edge type IDs, the edge types may not be loaded in a deterministic order.
 * [➞load_node_list_in_parallel](ensmallenRunConfig__load_node_list_in_parallel.md) - Whether to load the node list in parallel. When loading in parallel, without node IDs, the nodes may not be loaded in a deterministic order.
 * [➞load_node_type_list_in_parallel](ensmallenRunConfig__load_node_type_list_in_parallel.md) - Whether to load the node type list in parallel. Note that when loading in parallel, the internal order of the node type IDs may result changed across different iterations. We are working to get this to be stable.
 * [➞may_have_singleton_with_selfloops](ensmallenRunConfig__may_have_singleton_with_selfloops.md) - Whether the graph may be expected to have singleton nodes with selfloops. If it is said that it surely DOES NOT have any, it will allow for some speedups and lower mempry peaks.
 * [➞may_have_singletons](ensmallenRunConfig__may_have_singletons.md) - Whether the graph may be expected to have singleton nodes. If it is said that it surely DOES NOT have any, it will allow for some speedups and lower mempry peaks.
 * [➞minimum_edge_type_id](ensmallenRunConfig__minimum_edge_type_id.md) - The minimum edge type ID to be used when using numeric edge type IDs.
 * [➞minimum_node_id](ensmallenRunConfig__minimum_node_id.md) - The minimum node ID to be used, when loading the node IDs as numerical.
 * [➞minimum_node_type_id](ensmallenRunConfig__minimum_node_type_id.md) - The minimum node type ID to be used when using numeric node type IDs.
 * [➞name](ensmallenRunConfig__name.md)
 * [➞node_ids_column](ensmallenRunConfig__node_ids_column.md) - The name of the column of the node file from where to load the node IDs.
 * [➞node_ids_column_number](ensmallenRunConfig__node_ids_column_number.md) - The number of the column of the node file from where to load the node IDs
 * [➞node_list_comment_symbol](ensmallenRunConfig__node_list_comment_symbol.md) - The comment symbol to skip lines in the nodes file. Lines starting with this symbol will be skipped.
 * [➞node_list_header](ensmallenRunConfig__node_list_header.md) - Whether the nodes file has an header.
 * [➞node_list_is_correct](ensmallenRunConfig__node_list_is_correct.md) - Whether the nodes file can be assumed to be correct, i.e. does not have something wrong in it. If this parameter is passed as true on a malformed file, the constructor will crash.
 * [➞node_list_max_rows_number](ensmallenRunConfig__node_list_max_rows_number.md) - The maximum number of lines to be loaded from the nodes file.
 * [➞node_list_node_types_column](ensmallenRunConfig__node_list_node_types_column.md) - The name of the column of the node file from where to load the node types.
 * [➞node_list_node_types_column_number](ensmallenRunConfig__node_list_node_types_column_number.md) - The number of the column of the node file from where to load the node types.
 * [➞node_list_numeric_node_type_ids](ensmallenRunConfig__node_list_numeric_node_type_ids.md) - Whether to load the node types IDs in the node file to be numeric.
 * [➞node_list_rows_to_skip](ensmallenRunConfig__node_list_rows_to_skip.md) - Number of rows to skip in the node list file.
 * [➞node_list_separator](ensmallenRunConfig__node_list_separator.md) - The separator to use for the nodes file. Note that if this is not provided, one will be automatically detected among the following - comma, semi-column, tab and space.
 * [➞node_list_support_balanced_quotes](ensmallenRunConfig__node_list_support_balanced_quotes.md) - Whether to support balanced quotes.
 * [➞node_path](ensmallenRunConfig__node_path.md) - The path to the file with the unique node names.
 * [➞node_type_list_comment_symbol](ensmallenRunConfig__node_type_list_comment_symbol.md) - The comment symbol to skip lines in the node types file. Lines starting with this symbol will be skipped.
 * [➞node_type_list_header](ensmallenRunConfig__node_type_list_header.md) - Whether the node type file has an header.
 * [➞node_type_list_is_correct](ensmallenRunConfig__node_type_list_is_correct.md) - Whether the node types file can be assumed to be correct, i.e. does not have something wrong in it. If this parameter is passed as true on a malformed file, the constructor will crash.
 * [➞node_type_list_max_rows_number](ensmallenRunConfig__node_type_list_max_rows_number.md) - The maximum number of lines to be loaded from the node types file.
 * [➞node_type_list_rows_to_skip](ensmallenRunConfig__node_type_list_rows_to_skip.md) - The number of lines to skip in the node types file. The header is already skipped if it has been specified that the file has an header.
 * [➞node_type_list_separator](ensmallenRunConfig__node_type_list_separator.md) - The separator to use for the node types file.
 * [➞node_type_list_support_balanced_quotes](ensmallenRunConfig__node_type_list_support_balanced_quotes.md) - Whether to support balanced quotes.
 * [➞node_type_path](ensmallenRunConfig__node_type_path.md) - The path to the file with the unique node type names.
 * [➞node_types_column](ensmallenRunConfig__node_types_column.md) - Node type column name.
 * [➞node_types_column_number](ensmallenRunConfig__node_types_column_number.md) - Node type column number.
 * [➞node_types_ids_column](ensmallenRunConfig__node_types_ids_column.md) - Node type ID column name.
 * [➞node_types_ids_column_number](ensmallenRunConfig__node_types_ids_column_number.md) - Node type ID column number.
 * [➞node_types_number](ensmallenRunConfig__node_types_number.md) - The number of the unique node types. This will be used in order to allocate the correct size for the data structure.
 * [➞node_types_separator](ensmallenRunConfig__node_types_separator.md) - The node types separator.
 * [➞nodes_column](ensmallenRunConfig__nodes_column.md) - The name of the column of the node file from where to load the node names.
 * [➞nodes_column_number](ensmallenRunConfig__nodes_column_number.md) - The number of the column of the node file from where to load the node names.
 * [➞nodes_number](ensmallenRunConfig__nodes_number.md) - The expected number of nodes. Note that this must be the EXACT number of nodes in the graph.
 * [➞numeric_edge_type_ids](ensmallenRunConfig__numeric_edge_type_ids.md) - Whether the edge type names should be loaded as numeric values, i.e. casted from string to a numeric representation.
 * [➞numeric_node_ids](ensmallenRunConfig__numeric_node_ids.md) - Whether to load the numeric node IDs as numeric.
 * [➞numeric_node_type_ids](ensmallenRunConfig__numeric_node_type_ids.md) - Whether the node type names should be loaded as numeric values, i.e. casted from string to a numeric representation.
 * [➞skip_edge_types_if_unavailable](ensmallenRunConfig__skip_edge_types_if_unavailable.md) - Whether to skip the edge types without raising an error if these are unavailable.
 * [➞skip_node_types_if_unavailable](ensmallenRunConfig__skip_node_types_if_unavailable.md) - Whether to skip the node types without raising an error if these are unavailable.
 * [➞skip_weights_if_unavailable](ensmallenRunConfig__skip_weights_if_unavailable.md) - Whether to skip the weights without raising an error if these are unavailable.
 * [➞sources_column](ensmallenRunConfig__sources_column.md) - The name of the column of the edges file from where to load the source nodes.
 * [➞sources_column_number](ensmallenRunConfig__sources_column_number.md) - The number of the column of the edges file from where to load the source nodes.
 * [➞verbose](ensmallenRunConfig__verbose.md) - Whether to show a loading bar while reading the files. Note that, if parallel loading is enabled, loading bars will not be showed because they are a synchronization bottleneck.
 * [➞weights_column](ensmallenRunConfig__weights_column.md) - The name of the column of the edges file from where to load the edge weights.
 * [➞weights_column_number](ensmallenRunConfig__weights_column_number.md) - The number of the column of the edges file from where to load the edge weights.
 * [➞files](fileResourceContainer__files.md)
 * [➞desc](fileResource__desc.md) - File description.
 * [➞path](fileResource__path.md) - File path or url.
 * [➞evaluation_data](graphDataConfiguration__evaluation_data.md) - Input data for pipeline.
 * [➞graph](graphDataConfiguration__graph.md) - Graph configuration for pipeline
 * [➞source_data](graphDataConfiguration__source_data.md) - Compressed input data for pipeline (tar.gz).
 * [➞layers](layerContainer__layers.md) - Container of layers to be used to build the neural network.
 * [➞activation](layerParams__activation.md) - Activation layer type
 * [➞rate](layerParams__rate.md)
 * [➞units](layerParams__units.md)
 * [➞parameters](layer__parameters.md)
 * [➞type](layer__type.md) - Type of layer.
 * [➞metrics](metricContainer__metrics.md) - Metrics need to train a classifier.
 * [➞curve](metric__curve.md) - Area under curve (AUC) to be calculated.
 * [➞name](metric__name.md)
 * [➞type](metric__type.md)
 * [➞graph_data](neatConfiguration__graph_data.md) - Configuration for graph data.
 * [➞batch_size](nodeEmbeddingsParams__batch_size.md) - Number of nodes to include in a single batch.
 * [➞explore_weight](nodeEmbeddingsParams__explore_weight.md) - Weight on the probability of visiting a neighbor node to the one we're coming from in the random walk Having this higher tends the walks to be more like a Depth-First Search. Having this very high makes search more outward. Having this very low makes search very local. Equal to the inverse of q in the Node2Vec paper.
 * [➞iterations](nodeEmbeddingsParams__iterations.md) - Number of iterations.
 * [➞method_name](nodeEmbeddingsParams__method_name.md) - Name of the node embedding method.
 * [➞return_weight](nodeEmbeddingsParams__return_weight.md) - Weight on the probability of returning to the same node the walk just came from Having this higher tends the walks to be more like a Breadth-First Search. Having this very high  (> 2) makes search very local. Equal to the inverse of p in the Node2Vec paper.
 * [➞walk_length](nodeEmbeddingsParams__walk_length.md) - Maximal length of the walks.
 * [➞window_size](nodeEmbeddingsParams__window_size.md) - Size of the context and target nodes for node2vec.
 * [➞destination](nodeType__destination.md) - Destination node(s).
 * [➞source](nodeType__source.md) - Source node(s).
 * [➞neg_edge_filepath](posNegData__neg_edge_filepath.md) - Negative edges file path.
 * [➞pos_edge_filepath](posNegData__pos_edge_filepath.md) - Positive edges file path.
 * [➞max_iter](skLearnParams__max_iter.md) - Maximum iterations.
 * [➞random_state](skLearnParams__random_state.md) - Random seed.
 * [➞fit_config](tFKerasParams__fit_config.md) - Configuration for model fitting.
 * [➞layers_config](tFKerasParams__layers_config.md) - Configuration for instantiating layers for neural networks.
 * [➞loss](tFKerasParams__loss.md) - Loss function.
 * [➞metrics_config](tFKerasParams__metrics_config.md) - Metrics to be calculated after classifier training.
 * [➞optimizer](tFKerasParams__optimizer.md) - Optimizer function to be used during classifier training.
 * [➞target_path](target__target_path.md) - File path for saving results.
 * [➞train_data](trainValidData__train_data.md) - Positive and negative graph data for ML training.
 * [➞valid_data](trainValidData__valid_data.md) - Positive and negative graph data for ML validation.
 * [➞extra_args](upload__extra_args.md) - Extra keyword arguments (**kwargs).
 * [➞s3_bucket](upload__s3_bucket.md) - Bucket name.
 * [➞s3_bucket_dir](upload__s3_bucket_dir.md) - Bucket path.

### Enums

 * [activation_enum](activation_enum.md) - Enums containing possible values for activation functions.
 * [classifier_callback_mode_enum](classifier_callback_mode_enum.md) - Callback modes while fitting a classifier.
 * [edge_method_enum](edge_method_enum.md) - Enums containing possible values for node edge methods.
 * [node_embed_method_enum](node_embed_method_enum.md) - Enums containing possible values for node embedding methods.
 * [optimizer_enum](optimizer_enum.md) - Optimizers that can be implemented in the neural network.

### Subsets


### Types


#### Built in

 * **Bool**
 * **Decimal**
 * **ElementIdentifier**
 * **NCName**
 * **NodeIdentifier**
 * **URI**
 * **URIorCURIE**
 * **XSDDate**
 * **XSDDateTime**
 * **XSDTime**
 * **float**
 * **int**
 * **str**

#### Defined

 * [Boolean](types/Boolean.md)  (**Bool**)  - A binary (true or false) value
 * [Date](types/Date.md)  (**XSDDate**)  - a date (year, month and day) in an idealized calendar
 * [Datetime](types/Datetime.md)  (**XSDDateTime**)  - The combination of a date and time
 * [Decimal](types/Decimal.md)  (**Decimal**)  - A real number with arbitrary precision that conforms to the xsd:decimal specification
 * [Double](types/Double.md)  (**float**)  - A real number that conforms to the xsd:double specification
 * [Float](types/Float.md)  (**float**)  - A real number that conforms to the xsd:float specification
 * [Integer](types/Integer.md)  (**int**)  - An integer
 * [Ncname](types/Ncname.md)  (**NCName**)  - Prefix part of CURIE
 * [Nodeidentifier](types/Nodeidentifier.md)  (**NodeIdentifier**)  - A URI, CURIE or BNODE that represents a node in a model.
 * [Objectidentifier](types/Objectidentifier.md)  (**ElementIdentifier**)  - A URI or CURIE that represents an object in the model.
 * [String](types/String.md)  (**str**)  - A character string
 * [Time](types/Time.md)  (**XSDTime**)  - A time object represents a (local) time of day, independent of any particular day
 * [Uri](types/Uri.md)  (**URI**)  - a complete URI
 * [Uriorcurie](types/Uriorcurie.md)  (**URIorCURIE**)  - a URI or a CURIE
